[![PyPI version](https://badge.fury.io/py/opentargets-ontologyutils.svg)](https://badge.fury.io/py/opentargets-ontologyutils)

[![Build Status](https://travis-ci.com/opentargets/ontology-utils.svg?branch=master)](https://travis-ci.com/opentargets/ontology-utils)

[![codecov](https://codecov.io/gh/opentargets/ontology-utils/branch/master/graph/badge.svg)](https://codecov.io/gh/opentargets/ontology-utils)

Python package with a set of utilities to:
 - download latest version of specific ontologies (tested on EFO, ECO, HP, MP)
 - extract information from ontology OBO and OWL file format
 - query this information from memory
 - map ontology identifiers to other ontology identifiers
 - map ontology labels to relevant ontology identifiers
